#include <WScom.h>
#include <WSCfunctionList.h>
#include <WSCbase.h>

/**/

#include "Common.h"

/**/

//----------------------------------------------------------
//Function for the event procedure
//----------------------------------------------------------
void MainMenuExit(WSCbase* object){
  //do something...
	exit( 0 );
}
static WSCfunctionRegister  op("MainMenuExit",(void*)MainMenuExit);
